package cn.com.infosec.asn1.x509;

import cn.com.infosec.asn1.ASN1Choice;
import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1OctetString;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.ASN1TaggedObject;
import cn.com.infosec.asn1.DEREncodable;
import cn.com.infosec.asn1.DERIA5String;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DERObjectIdentifier;
import cn.com.infosec.asn1.DEROctetString;
import cn.com.infosec.asn1.DERTaggedObject;
import cn.com.infosec.util.IPAddress;

public class GeneralName extends ASN1Encodable implements ASN1Choice {
   public static final int otherName = 0;
   public static final int rfc822Name = 1;
   public static final int dNSName = 2;
   public static final int x400Address = 3;
   public static final int directoryName = 4;
   public static final int ediPartyName = 5;
   public static final int uniformResourceIdentifier = 6;
   public static final int iPAddress = 7;
   public static final int registeredID = 8;
   DEREncodable obj;
   int tag;

   public GeneralName(X509Name dirName) {
      this.obj = dirName;
      this.tag = 4;
   }

   /** @deprecated */
   public GeneralName(DERObject name, int tag) {
      this.obj = name;
      this.tag = tag;
   }

   public GeneralName(int tag, ASN1Encodable name) {
      this.obj = name;
      this.tag = tag;
   }

   public GeneralName(int tag, String name) {
      this.tag = tag;
      if (tag != 1 && tag != 2 && tag != 6) {
         if (tag == 8) {
            DERObjectIdentifier var5;
            var5 = new DERObjectIdentifier.<init>(name);
            this.obj = var5;
         } else if (tag == 4) {
            X509Name var6;
            var6 = new X509Name.<init>(name);
            this.obj = var6;
         } else {
            if (tag != 7) {
               throw new IllegalArgumentException("can't process String for tag: " + tag);
            }

            if (!IPAddress.isValid(name)) {
               throw new IllegalArgumentException("IP Address is invalid");
            }

            String[] tag1 = name.split("\\.");
            byte[] name1 = new byte[4];

            for(int var3 = 0; var3 < 4; ++var3) {
               name1[var3] = (byte)Integer.parseInt(tag1[var3]);
            }

            DEROctetString var8;
            var8 = new DEROctetString.<init>(name1);
            this.obj = var8;
         }
      } else {
         DERIA5String var4;
         var4 = new DERIA5String.<init>(name);
         this.obj = var4;
      }

   }

   public static GeneralName getInstance(Object obj) {
      if (obj != null && !(obj instanceof GeneralName)) {
         if (obj instanceof ASN1TaggedObject) {
            ASN1TaggedObject var1;
            int var2;
            switch (var2 = (var1 = (ASN1TaggedObject)obj).getTagNo()) {
               case 0:
                  return new GeneralName(var2, ASN1Sequence.getInstance(var1, false));
               case 1:
                  return new GeneralName(var2, DERIA5String.getInstance(var1, false));
               case 2:
                  return new GeneralName(var2, DERIA5String.getInstance(var1, false));
               case 3:
                  throw new IllegalArgumentException("unknown tag: " + var2);
               case 4:
                  return new GeneralName(var2, ASN1Sequence.getInstance(var1, true));
               case 5:
                  return new GeneralName(var2, ASN1Sequence.getInstance(var1, false));
               case 6:
                  return new GeneralName(var2, DERIA5String.getInstance(var1, false));
               case 7:
                  return new GeneralName(var2, ASN1OctetString.getInstance(var1, false));
               case 8:
                  return new GeneralName(var2, DERObjectIdentifier.getInstance(var1, false));
            }
         }

         throw new IllegalArgumentException("unknown object in getInstance: " + obj.getClass().getName());
      } else {
         return (GeneralName)obj;
      }
   }

   public static GeneralName getInstance(ASN1TaggedObject tagObj, boolean explicit) {
      return getInstance(ASN1TaggedObject.getInstance(tagObj, true));
   }

   public int getTagNo() {
      return this.tag;
   }

   public DEREncodable getName() {
      return this.obj;
   }

   public String toString() {
      StringBuffer var1;
      StringBuffer var10001 = var1 = new StringBuffer;
      var1.<init>();
      var10001.append(this.tag);
      var10001.append(": ");
      int var2;
      if ((var2 = this.tag) != 1 && var2 != 2) {
         if (var2 == 4) {
            var1.append(X509Name.getInstance(this.obj).toString());
            return var1.toString();
         }

         if (var2 != 6) {
            var1.append(this.obj.toString());
            return var1.toString();
         }
      }

      var1.append(DERIA5String.getInstance(this.obj).getString());
      return var1.toString();
   }

   public DERObject toASN1Object() {
      int var1;
      DEREncodable var2;
      if ((var1 = this.tag) == 4) {
         var2 = this.obj;
         return new DERTaggedObject(true, var1, var2);
      } else {
         var2 = this.obj;
         return new DERTaggedObject(false, var1, var2);
      }
   }
}
